#
# spec file for package jdepend
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jdepend
Version:        2.10
Release:        4.4
Summary:        Java Design Quality Metrics
License:        MIT
Group:          Development/Libraries/Java
URL:            http://www.clarkware.com/software/JDepend.html
Source0:        https://github.com/clarkware/jdepend/archive/refs/tags/%{version}.tar.gz
Source1:        %{name}-%{version}.pom
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel
BuildRequires:  javapackages-local >= 6
BuildArch:      noarch

%description
JDepend traverses a set of Java class and source file directories and
generates design quality metrics for each Java package. JDepend allows
you to automatically measure the quality of a design in terms of its
extensibility, reusability, and maintainability to effectively manage
and control package dependencies.

%package demo
Summary:        Demonstration and sample files for jdepend
Group:          Development/Libraries/Java
Requires:       %{name} = %{version}-%{release}

%description demo
JDepend traverses a set of Java class and source file directories and
generates design quality metrics for each Java package. JDepend allows
you to automatically measure the quality of a design in terms of its
extensibility, reusability, and maintainability to effectively manage
and control package dependencies.

This package contains demonstration and sample files for JDepend.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
# remove all binary libs
find . -name "*.jar" -exec rm -f {} \;

%build
%{ant} \
	-Dant.build.javac.source=1.8 \
	-Dant.build.javac.target=1.8 \
	jar javadoc

%install
# jars
install -d -m 0755 %{buildroot}%{_javadir}
install -p -m 0644 dist/%{name}-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}.jar

# pom
install -d -m 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} %{SOURCE1} %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar

# javadoc
install -d -m 0755 %{buildroot}%{_javadocdir}
cp -pr build/docs/api %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

# # demo
install -d -m 755 %{buildroot}%{_datadir}/%{name}
cp -pr sample %{buildroot}%{_datadir}/%{name}
%fdupes -s %{buildroot}%{_datadir}/%{name}

%files -f .mfiles
%license LICENSE.md
%doc CHANGELOG.md README.md

%files javadoc
%{_javadocdir}/%{name}

%files demo
%{_datadir}/%{name}

%changelog
* Tue Apr 30 2024 Fridrich Strba <fstrba@suse.com>
- Simplify the spec:
  * remove old macros,
  * avoid versioned jars,
  * build and distribute javadoc
* Sat Jun 18 2022 Fridrich Strba <fstrba@suse.com>
- Clean-up the spec file
* Sat Mar 19 2022 Fridrich Strba <fstrba@suse.com>
- Specify the source/target levels 8 on ant invocation
- Removed patch:
  * jdepend-target16.patch
    + not needed with the source/target levels being specified on
    command-line
* Tue Dec 28 2021 David Anes <david.anes@suse.com>
- Update to 2.10:
  * Official release that includes support for Java 8 constants
- Updated license from BSD-3 Clause to MIT (as per LICENSE.md file).
- Fix installed files permissions (were too broad).
- Fix LICENSE, CHANGES and README permissions.
- Fix demo permissions (were too broad).
- Rebased patches:
  * jdepend-target16.patch
* Tue Nov 27 2018 Fridrich Strba <fstrba@suse.com>
- Add maven pom file
* Fri Sep  8 2017 fstrba@suse.com
- Removed patch:
  * jdepend-target15.patch
- Added patch:
  * jdepend-target16.patch
    + Specify java source and target levels 1.6 in order to allow
    building with jdk9
* Fri Jun  9 2017 tchvatal@suse.com
- Drop javadoc so we build with gcj properly
* Fri Aug 29 2008 mvyskocil@suse.cz
- source=1.5 -target=1.5
- bzipped source code
- removed the gcj support
- removed a javadoc scripplets
* Fri Mar 14 2008 mvyskocil@suse.cz
- merged with jpackage 1.7:
- update to version 2.9.1
- removed a java14compat patch
- added a gcj build support
- added post(un) scripts for javadoc subpackage
* Thu Mar 29 2007 ro@suse.de
- added unzip to buildreq
* Mon Sep 25 2006 skh@suse.de
- don't use icecream
- use source="1.4" and target="1.4" for build with java 1.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jul 28 2005 jsmeix@suse.de
- Adjustments in the spec file.
* Mon Jul 18 2005 jsmeix@suse.de
- Current version 2.6 from JPackage.org
* Thu Sep  2 2004 skh@suse.de
- Initial package created with version 2.6 (JPackage 1.5)
